'use strict';

/*
 * This tests a flow for the cloudron 'user. The cloudron
 * owner create a new user. This new user should be able to
 * login with the resetToken.
 */

var AppStore = require('../appstore.js'),
    Cloudron = require('../cloudron.js'),
    common = require('../common.js');

require('colors');

process.env.NODE_TLS_REJECT_UNAUTHORIZED = '0';
var BOX_VERSION = process.env.BOX_VERSION;

describe('Cloudron user creation testing', function () {
    this.timeout(0);

    var appStore = new AppStore('https://api.staging.cloudron.io');

    var owner = common.getOwner();
    var admin = common.getAdmin();
    var cloudron, box, newUser;

    it('can login to the store', function () {
        var accessToken = appStore.getAccessToken(owner);
        appStore.setCredentials(owner.password, accessToken);

        var adminAccessToken = appStore.getAccessToken(admin);
        appStore.setAdminCredentials(admin.password, adminAccessToken);
    });

    it('can create a cloudron', function () {
        box = appStore.createCloudron({
            domain: common.cloudronDomain(__filename),
            region: 'ams3',
            size: '1gb',
            version: BOX_VERSION
        });
        box = appStore.waitForCloudron(box.id);
        cloudron = new Cloudron(box);
    });

    it('can activate the box', function () {
        cloudron.activate(owner);
    });

    it('can login to the box', function () {
        var token = cloudron.getOauthToken(owner);
        cloudron.setCredentials(owner.password, token);
    });

    it('can create user', function () {
        newUser = cloudron.addUser('newuser', 'test+foo@cloudron.io');
    });

    it('can use reset token to reset password', function () {
        cloudron.resetPassword(newUser.resetToken, 'Strong?132');
    });

    it('can login as new user', function () {
        cloudron.getOauthToken({ username: 'newuser', password: 'Strong?132' });
    });

    it('can delete the cloudron', function () {
        appStore.deleteCloudron(box);
    });

});

